==> dl.php?src=linea21_1_7.zip: linea21/languages/fr/lang_dashboard.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage fr
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['dashboard']['section'] = "tableau de bord";

/*	nommage des modules
 *  	*/
$lang['dashboard']['name'] = "valeur";
$lang['dashboard']['name_pluriel'] = 'valeur(s)';
$lang['dashboard']['confirm_add'] = "Ajout de la valeur réalisé avec succès\n";
$lang['dashboard']['confirm_mod'] = "Modification de la valeur réalisée avec succès\n";
$lang['dashboard']['confirm_sup'] = "Suppression de la valeur réalisée avec succès\n";




/*	nommage public
 *  	*/
$lang['dashboard']['list_public']="Tableau de bord";

$lang['dashboard']['h1_public_comment']="Le tableau de bord vous propose une vision groupée des différents indicateurs constituant l'évaluation de notre approche de développement durable.<br />";
$lang['dashboard']['h1_public_comment_anim']="Le tableau de bord représente le bilan développement durable de votre ville.<br />";

$lang['dashboard']['mode_aff']="Mode d'affichage";
$lang['dashboard']['mode_by_project']="Vue par projet";
$lang['dashboard']['mode_by_finality']="Vue par finalité";
$lang['dashboard']['mode_aff_info']="Infos générales";
$lang['dashboard']['mode_aff_evaluation']="Critères d'évaluation";
$lang['dashboard']['mode_aff_provider']="Fournisseur";
$lang['dashboard']['mode_aff_rules']="Réglementation";
$lang['sdi']['goal_public']="Les objectifs de vos élus";
$lang['sdi']['consulting_public']="Conseils pour améliorer cet indicateur au quotidien";


$lang['dashboard']['tab-attached']='Tableau de bord';
$lang['dashboard']['tab-not-attached']='Indicateurs indépendants';
$lang['dashboard']['tab-all']='Tous';

/* informations affichages tableau
 * */
$lang['dashboard']['list_public_summary']="Valeurs des indicateurs pour %s";
$lang['dashboard']['graphic_value']="valeur graphique";
$lang['dashboard']['numeric_value']="valeur numérique";
$lang['dashboard']['tendencies_value']="tendances";
$lang['dashboard']['label_value']="nom de l'indicateur";

$lang['dashboard']['evaluation_values_summary']="Valeurs des critères d'évaluation pour l'indicateur courant";
$lang['dashboard']['all_values_summary']="Tableau des valeurs de l'indicateur courant";

/*	nommage rubrique module
 *  	*/
$lang['dashboard']['add'] = "Ajout d'une " . $lang['dashboard']['name'];
$lang['dashboard']['rap'] = "Édition d'un rapport global";
$lang['dashboard']['mod'] = "Modification de la valeur";
$lang['dashboard']['sup'] = "Suppression d'une " . $lang['dashboard']['name'];
$lang['dashboard']['det'] = "Valeurs de l'indicateur";
$lang['dashboard']['list'] = "Tableau de bord ";


/*	nommage rubrique add / mod /det
 *  	*/
$lang['dashboard']['add_title1'] = "Saisie de la nouvelle " . $lang['dashboard']['name'];
$lang['dashboard']['recap_commment'] = "aucun commentaire";
$lang['dashboard']['confirmation'] = "confirmer l'inscription";


/*	nommage rubrique sup
 *  	*/
$lang['dashboard']['sup_value_warning'] = "Etes vous sur de vouloir supprimer définitivement cette " . $lang['dashboard']['name'] . "?";


/*	nommage élément rubrique

*  	*/
$lang['dashboard']['value'] = "valeur de l'indicateur";
$lang['dashboard']['threshold_value'] = "valeur seuil";
$lang['dashboard']['historic'] = "Bilan de l'indicateur";
$lang['dashboard']['rep_graph'] = "Représentation graphique de l'indicateur";
$lang['dashboard']['sdi_info'] = "nom de l'indicateur";
$lang['dashboard']['scale'] = "échelle de mesure de la valeur";
$lang['dashboard']['date'] = "date de publication";
$lang['dashboard']['day'] = "jour";
$lang['dashboard']['month'] = "mois";
$lang['dashboard']['year'] = "année";
$lang['dashboard']['rate'] = "taux d'évolution";
$lang['dashboard']['comment'] = "commentaire";
$lang['dashboard']['comment_status'] = "statut du commentaire";
$lang['dashboard']['public'] = "public";
$lang['dashboard']['private'] = "privé";
$lang['dashboard']['previous_value'] = "valeur précédente : %s";

/*	nommage quickbox
 *  	*/
$lang['dashboard']['qb_add_title'] = " derniers ajouts effectués dans : ";
$lang['dashboard']['qb_mod_title'] = " dernières modifications effectuées dans : ";




/*	rapport
 *  	*/
$lang['dashboard']['rap_scale_choice'] = "Choisir les échelles";
$lang['dashboard']['rap_scale_all'] = "Ajouter toutes les échelles";
$lang['dashboard']['rap_scale_det'] = "Choisir les échelles";
$lang['dashboard']['rap_sdi_choice'] = "Choisir les indicateurs";
$lang['dashboard']['rap_sdi_all'] = "Ajouter tous les indicateurs";
$lang['dashboard']['rap_sdi_det'] = "Choisir les indicateurs";
$lang['dashboard']['rap_comp_choice'] = "Choisir les informations complémentaires";
$lang['dashboard']['rap_graph_values'] = "Ajouter les graphiques de valeur dans le rapport ";
$lang['dashboard']['rap_table_values'] = "Ajouter l'ensemble des valeurs pour chaque indicateur";
$lang['dashboard']['rap_notpublished_values'] = "Faire apparaître les valeurs non publiées";
$lang['dashboard']['rap_provider_info'] = "Ajouter les informations de fournisseurs pour chaque indicateur";
$lang['dashboard']['rap_rules_info'] = "Ajouter les informations de réglementations pour chaque indicateur";
$lang['dashboard']['rap_eval_info'] = "Ajouter les critères d'évaluation pour chaque indicateur";
$lang['dashboard']['rap_summary_info'] = "Générer un index";
$lang['dashboard']['rap_publi_info'] = "Ajouter les informations de génération du document en fin de rapport";
$lang['dashboard']['rap_author'] = "Auteur du rapport";
$lang['dashboard']['rap_mail_author'] = "mail de l'auteur";
$lang['dashboard']['rap_service'] = "Service";
$lang['dashboard']['rap_adress'] = "Adresse complète";
$lang['dashboard']['rap_title'] = "Titre du rapport";
$lang['dashboard']['rap_no_values_for'] = 'Pas de valeurs pour les échelles suivantes : ';
$lang['dashboard']['rap_insuffisant_values'] = 'Données insuffisantes pour génération de graphique sur les échelles suivantes :';
$lang['dashboard']['rap_scale'] = "échelles séléctionnées";
$lang['dashboard']['rap_indicators'] = "indicateurs séléctionnés";
$lang['dashboard']['rap_generated'] = "rapport généré en ";
$lang['dashboard']['rap_infopubli'] = "Informations de publication";
$lang['dashboard']['rap_summary'] = "Index - accès rapide";
$lang['dashboard']['rap_save'] = "enregistrer";
$lang['dashboard']['rap_generate'] = "générer";
$lang['dashboard']['select_by_finalities'] = "... par finalités";
$lang['dashboard']['select_by_association'] = "... par association";
$lang['dashboard']['indicator-attached']='Indicateurs attachés au tableau de bord';
$lang['dashboard']['indicator-not-attached']='Indicateurs indépendants (rattachés aux actions)';

/*	divers
 *  	*/
$lang['dashboard']['select_choice'] = "-- Faites votre choix dans la liste ci dessous --";
$lang['dashboard']['facultatif'] = "facultatif";
$lang['dashboard']['aff_dashboard_e'] = "Afficher les critères d'évaluation";
$lang['dashboard']['aff_dashboard_r'] = "Afficher les références réglementaires";
$lang['dashboard']['aff_dashboard_p'] = "Afficher les coordonnées du fournisseur";
$lang['dashboard']['novalue'] = "Aucune valeur";
$lang['dashboard']['value_tendance'] = "Tendance globale de  l'indicateur";
$lang['dashboard']['tendance_asc'] = "ascendante";
$lang['dashboard']['tendance_desc'] = "descendante";
$lang['dashboard']['all_value'] = "Ensemble des valeurs pour cet indicateur";
$lang['dashboard']['barre'] = "Positionnement de l'indicateur par rapport à sa valeur seuil";
$lang['dashboard']['global_value'] = "valeur globale";
$lang['dashboard']['det_sdi'] = "afficher les informations générales de l'indicateur";
$lang['dashboard']['det_sdi2'] = "Informations générales";


/*	messages
 *  	*/


$lang['dashboard']['object_notvalue'] = "Vous devez impérativement saisir une valeur numérique pour cet indicateur.";
$lang['dashboard']['object_notgoodvalue'] = "Vous devez impérativement saisir une valeur comprise dans les limites de mesure.";


/*	rubrique d'aide
 *  	*/
$lang['dashboard']['help_add1'] = "Pour ajouter une valeur, vous devez saisir chacun de ces paramètres dans le formulaire ci-dessus";
$lang['dashboard']['help_add2'] = "Vous pouvez cliquer sur \"informations de mesure\" pour obtenir les valeurs seuil, minimale, maximale et la fréquence de collecte de cet indicateur";
$lang['dashboard']['help_add3'] = "Vous pouvez cliquer sur \"" . $lang['dashboard']['all_value'] . "\" pour afficher toutes les valeurs de cet indicateur pour cette échelle";
$lang['dashboard']['help_add4'] = "Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \"revoir les paramètres\" pour les modifier";
$lang['dashboard']['help_add5'] = "Vous devez absolument saisir une valeur numérique comprise entre les valeurs minimale et maximale prévues pour cet indicateur";
$lang['dashboard']['help_add6'] = "Les champs marqués d'un astérisque sont obligatoires";


$lang['dashboard']['help_list1'] = "Pour afficher les valeurs d'un couple indicateur/échelle en détails, cliquez sur le nom de cet indicateur.";
$lang['dashboard']['help_list2'] = "Vous pouvez ajouter une valeur à un couple indicateur/échelle en cliquant sur l'icône d'ajout qui lui est associée.";
$lang['dashboard']['help_list3'] = "Vous pouvez sélectionner une autre échelle, le tableau de bord est alors mis à jour : l'ensemble des indicateurs de cette échelle apparaît alors sur le tableau de bord.";
$lang['dashboard']['help_list4'] = "Chaque indicateur est associé à un compteur visuel vous permettant une vision globale du tableau de bord pour une échelle donnée : si le curseur du compteur est au dela du seuil, la dernière valeur enregistrée pour cet indicateur a dépassé le seuil fixé";
$lang['dashboard']['help_list5'] = "Si l'indicateur, pour une échelle donnée, compte plus de deux valeurs, une icône de tendance apparaît alors à côté du compteur visuel";
$lang['dashboard']['help_list6'] = "La dernière valeur de l'indicateur, pour une échelle donnée, est rappellée à côté du compteur visuel.";
$lang['dashboard']['help_list7'] = "Un compteur visuel global est présent en haut de page, et vous permet une vision globale de votre  de bord pour une échelle donnée.";
$lang['dashboard']['help_list8'] = "Astuce : laisser immobile votre curseur sur les différents éléments de la page affichera des informations complémentaires en info-bulle.";


$lang['dashboard']['help_mod1'] = "Pour modifier une valeur, vous pouvez modifier chacun de ces paramètres dans le formulaire ci-dessus";
$lang['dashboard']['help_mod2'] = "Vous pouvez cliquer sur \"informations de mesure\" pour obtenir les valeurs seuil, minimale, maximale et la fréquence de collecte de cet indicateur";
$lang['dashboard']['help_mod3'] = "Vous pouvez cliquer sur \"" . $lang['dashboard']['all_value'] . "\" pour afficher toutes les valeurs de cet indicateur pour cette échelle";
$lang['dashboard']['help_mod4'] = "Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \"revoir les paramètres\" pour les modifier";
$lang['dashboard']['help_mod5'] = "Vous devez absolument saisir une valeur numérique comprise entre les valeurs minimale et maximale prévues pour cet indicateur";
$lang['dashboard']['help_mod6'] = "Les champs marqués d'un astérisque sont obligatoires";


$lang['dashboard']['help_rap1'] = "Le rapport est édité au format pdf et lisible avec Acrobat reader";
$lang['dashboard']['help_rap2'] = "Faites le choix entre les différentes options proposées ci-dessus pour éditer votre rapport";
$lang['dashboard']['help_rap3'] = "Vous pouvez annuler l'édition du rapport à tout moment en cliquant sur annuler";


$lang['dashboard']['help_det2'] = "Vous pouvez ajouter une valeur à ce couple indicateur/échelle en cliquant sur l'icône d'ajout qui lui est associée en haut de page";
$lang['dashboard']['help_det3'] = "Vous pouvez modifier une valeur en cliquant sur l'icône de modification qui lui est associée";
$lang['dashboard']['help_det4'] = "Vous pouvez supprimer une valeur en cliquant sur l'icône de suppression qui lui est associée";
$lang['dashboard']['help_det1'] = "Attention, une valeur est associée à un indicateur mais aussi à une échelle";
$lang['dashboard']['help_det5'] = "Pour afficher les informations générales d'un indicateur, de réglementation, fournisseurs, et critères d'évaluation, cliquer sur afficher ces informations en bas de page.";


$lang['dashboard']['help_sup1'] = "En cliquant sur valider, la valeur est définitivement suppprimée.";
$lang['dashboard']['help_sup2'] = "Si vous voulez simplement désactiver la valeur, positionnez la en statut \"brouillon\" dans modification de valeur.";
?>

==> dl.php?src=linea21_1_8.zip: linea21/languages/fr/lang_dashboard.utf-8.php <==
<?php
/**
 * @package linea21\languages\fr
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['dashboard']['section'] = "tableau de bord";

/*	nommage des modules
 *  	*/
$lang['dashboard']['name'] = "valeur";
$lang['dashboard']['name_pluriel'] = 'valeur(s)';
$lang['dashboard']['confirm_add'] = "Ajout de la valeur réalisé avec succès\n";
$lang['dashboard']['confirm_mod'] = "Modification de la valeur réalisée avec succès\n";
$lang['dashboard']['confirm_sup'] = "Suppression de la valeur réalisée avec succès\n";




/*	nommage public
 *  	*/
$lang['dashboard']['list_public']="Tableau de bord";

$lang['dashboard']['h1_public_comment']="Le tableau de bord vous propose une vision groupée des différents indicateurs constituant l'évaluation de notre approche de développement durable.<br />";
$lang['dashboard']['h1_public_comment_anim']="Le tableau de bord représente le bilan développement durable de votre ville.<br />";

$lang['dashboard']['mode_aff']="Mode d'affichage";
$lang['dashboard']['mode_by_project']="Vue par projet";
$lang['dashboard']['mode_by_finality']="Vue par finalité";
$lang['dashboard']['mode_aff_info']="Infos générales";
$lang['dashboard']['mode_aff_evaluation']="Critères d'évaluation";
$lang['dashboard']['mode_aff_provider']="Fournisseur";
$lang['dashboard']['mode_aff_rules']="Réglementation";
$lang['sdi']['goal_public']="Les objectifs de vos élus";
$lang['sdi']['consulting_public']="Conseils pour améliorer cet indicateur au quotidien";


$lang['dashboard']['tab-attached']='Tableau de bord';
$lang['dashboard']['tab-not-attached']='Indicateurs indépendants';
$lang['dashboard']['tab-all']='Tous';

$lang['dashboard']['export_to_excel']='Exporter les valeurs au format Excel';

/* informations affichages tableau
 * */
$lang['dashboard']['list_public_summary']="Valeurs des indicateurs pour %s";
$lang['dashboard']['graphic_value']="valeur graphique";
$lang['dashboard']['numeric_value']="valeur numérique";
$lang['dashboard']['tendencies_value']="tendances";
$lang['dashboard']['label_value']="nom de l'indicateur";

$lang['dashboard']['multivalue_label']="label";
$lang['dashboard']['multivalue_value']="valeur";
$lang['dashboard']['multivalue_total']="total";

$lang['dashboard']['to_detail_chart']="voir la répartition";
$lang['dashboard']['negative_values_notice']="[valeurs négatives non affichées]";

$lang['dashboard']['evaluation_values_summary']="Valeurs des critères d'évaluation pour l'indicateur courant";
$lang['dashboard']['all_values_summary']="Tableau des valeurs de l'indicateur courant";

/*	nommage rubrique module
 *  	*/
$lang['dashboard']['add'] = "Ajout d'une " . $lang['dashboard']['name'];
$lang['dashboard']['rap'] = "Édition d'un rapport global";
$lang['dashboard']['mod'] = "Modification de la valeur";
$lang['dashboard']['sup'] = "Suppression d'une " . $lang['dashboard']['name'];
$lang['dashboard']['det'] = "Valeurs de l'indicateur";
$lang['dashboard']['list'] = "Tableau de bord ";


/*	nommage rubrique add / mod /det
 *  	*/
$lang['dashboard']['add_title1'] = "Saisie de la nouvelle " . $lang['dashboard']['name'];
$lang['dashboard']['recap_commment'] = "aucun commentaire";
$lang['dashboard']['confirmation'] = "confirmer l'inscription";


/*	nommage rubrique sup
 *  	*/
$lang['dashboard']['sup_value_warning'] = "Etes vous sur de vouloir supprimer définitivement cette " . $lang['dashboard']['name'] . "?";


/*	nommage élément rubrique

*  	*/
$lang['dashboard']['value'] = "valeur de l'indicateur";
$lang['dashboard']['threshold_value'] = "valeur seuil";
$lang['dashboard']['historic'] = "Bilan de l'indicateur";
$lang['dashboard']['rep_graph'] = "Représentation graphique de l'indicateur";
$lang['dashboard']['sdi_info'] = "nom de l'indicateur";
$lang['dashboard']['scale'] = "échelle de mesure de la valeur";
$lang['dashboard']['date'] = "date de publication";
$lang['dashboard']['day'] = "jour";
$lang['dashboard']['month'] = "mois";
$lang['dashboard']['year'] = "année";
$lang['dashboard']['rate'] = "taux d'évolution";
$lang['dashboard']['comment'] = "commentaire";
$lang['dashboard']['comment_status'] = "statut du commentaire";
$lang['dashboard']['public'] = "public";
$lang['dashboard']['private'] = "privé";
$lang['dashboard']['previous_value'] = "valeur précédente : %s";

/*	nommage quickbox
 *  	*/
$lang['dashboard']['qb_add_title'] = " derniers ajouts effectués dans : ";
$lang['dashboard']['qb_mod_title'] = " dernières modifications effectuées dans : ";




/*	rapport
 *  	*/
$lang['dashboard']['rap_scale_choice'] = "Choisir les échelles";
$lang['dashboard']['rap_scale_all'] = "Ajouter toutes les échelles";
$lang['dashboard']['rap_scale_det'] = "Choisir les échelles";
$lang['dashboard']['rap_sdi_choice'] = "Choisir les indicateurs";
$lang['dashboard']['rap_sdi_all'] = "Ajouter tous les indicateurs";
$lang['dashboard']['rap_sdi_det'] = "Choisir les indicateurs";
$lang['dashboard']['rap_comp_choice'] = "Choisir les informations complémentaires";
$lang['dashboard']['rap_graph_values'] = "Ajouter les graphiques de valeur dans le rapport ";
$lang['dashboard']['rap_table_values'] = "Ajouter l'ensemble des valeurs pour chaque indicateur";
$lang['dashboard']['rap_notpublished_values'] = "Faire apparaître les valeurs non publiées";
$lang['dashboard']['rap_provider_info'] = "Ajouter les informations de fournisseurs pour chaque indicateur";
$lang['dashboard']['rap_rules_info'] = "Ajouter les informations de réglementations pour chaque indicateur";
$lang['dashboard']['rap_eval_info'] = "Ajouter les critères d'évaluation pour chaque indicateur";
$lang['dashboard']['rap_summary_info'] = "Générer un index";
$lang['dashboard']['rap_publi_info'] = "Ajouter les informations de génération du document en fin de rapport";
$lang['dashboard']['rap_author'] = "Auteur du rapport";
$lang['dashboard']['rap_mail_author'] = "mail de l'auteur";
$lang['dashboard']['rap_service'] = "Service";
$lang['dashboard']['rap_adress'] = "Adresse complète";
$lang['dashboard']['rap_title'] = "Titre du rapport";
$lang['dashboard']['rap_no_values_for'] = 'Pas de valeurs pour les échelles suivantes : ';
$lang['dashboard']['rap_insuffisant_values'] = 'Données insuffisantes pour génération de graphique sur les échelles suivantes : ';
$lang['dashboard']['rap_scale'] = "échelles sélectionnées";
$lang['dashboard']['rap_indicators'] = "indicateurs sélectionnés";
$lang['dashboard']['rap_generated'] = "rapport généré en ";
$lang['dashboard']['rap_infopubli'] = "Informations de publication";
$lang['dashboard']['rap_summary'] = "Index - accès rapide";
$lang['dashboard']['rap_save'] = "enregistrer";
$lang['dashboard']['select_by_finalities'] = "... par finalités";
$lang['dashboard']['select_by_association'] = "... par association";
$lang['dashboard']['indicator-attached']='Indicateurs attachés au tableau de bord';
$lang['dashboard']['indicator-not-attached']='Indicateurs indépendants (rattachés aux actions)';

/*	divers
 *  	*/
$lang['dashboard']['select_choice'] = "-- Faites votre choix dans la liste ci dessous --";
$lang['dashboard']['facultatif'] = "facultatif";
$lang['dashboard']['aff_dashboard_e'] = "Afficher les critères d'évaluation";
$lang['dashboard']['aff_dashboard_r'] = "Afficher les références réglementaires";
$lang['dashboard']['aff_dashboard_p'] = "Afficher les coordonnées du fournisseur";
$lang['dashboard']['novalue'] = "Aucune valeur";
$lang['dashboard']['value_tendance'] = "Tendance globale de  l'indicateur";
$lang['dashboard']['tendance_asc'] = "ascendante";
$lang['dashboard']['tendance_desc'] = "descendante";
$lang['dashboard']['all_value'] = "Ensemble des valeurs pour cet indicateur";
$lang['dashboard']['barre'] = "Positionnement de l'indicateur par rapport à sa valeur seuil";
$lang['dashboard']['global_value'] = "valeur globale";
$lang['dashboard']['det_sdi'] = "afficher les informations générales de l'indicateur";
$lang['dashboard']['det_sdi2'] = "Informations générales";


/*	messages
 *  	*/


$lang['dashboard']['object_notvalue'] = "Vous devez impérativement saisir une valeur numérique pour cet indicateur.";
$lang['dashboard']['object_notgoodvalue'] = "Vous devez impérativement saisir une valeur comprise dans les limites de mesure.";


/*	rubrique d'aide
 *  	*/
$lang['dashboard']['help_add1'] = "Pour ajouter une valeur, vous devez saisir chacun de ces paramètres dans le formulaire ci-dessus";
$lang['dashboard']['help_add2'] = "Vous pouvez cliquer sur \"informations de mesure\" pour obtenir les valeurs seuil, minimale, maximale et la fréquence de collecte de cet indicateur";
$lang['dashboard']['help_add3'] = "Vous pouvez cliquer sur \"" . $lang['dashboard']['all_value'] . "\" pour afficher toutes les valeurs de cet indicateur pour cette échelle";
$lang['dashboard']['help_add4'] = "Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \"revoir les paramètres\" pour les modifier";
$lang['dashboard']['help_add5'] = "Vous devez absolument saisir une valeur numérique comprise entre les valeurs minimale et maximale prévues pour cet indicateur";
$lang['dashboard']['help_add6'] = "Les champs marqués d'un astérisque sont obligatoires";


$lang['dashboard']['help_list1'] = "Pour afficher les valeurs d'un couple indicateur/échelle en détails, cliquez sur le nom de cet indicateur.";
$lang['dashboard']['help_list2'] = "Vous pouvez ajouter une valeur à un couple indicateur/échelle en cliquant sur l'icône d'ajout qui lui est associée.";
$lang['dashboard']['help_list3'] = "Vous pouvez sélectionner une autre échelle, le tableau de bord est alors mis à jour : l'ensemble des indicateurs de cette échelle apparaît alors sur le tableau de bord.";
$lang['dashboard']['help_list4'] = "Chaque indicateur est associé à un compteur visuel vous permettant une vision globale du tableau de bord pour une échelle donnée : si le curseur du compteur est au dela du seuil, la dernière valeur enregistrée pour cet indicateur a dépassé le seuil fixé";
$lang['dashboard']['help_list5'] = "Si l'indicateur, pour une échelle donnée, compte plus de deux valeurs, une icône de tendance apparaît alors à côté du compteur visuel";
$lang['dashboard']['help_list6'] = "La dernière valeur de l'indicateur, pour une échelle donnée, est rappellée à côté du compteur visuel.";
$lang['dashboard']['help_list7'] = "Un compteur visuel global est présent en haut de page, et vous permet une vision globale de votre  de bord pour une échelle donnée.";
$lang['dashboard']['help_list8'] = "Astuce : laisser immobile votre curseur sur les différents éléments de la page affichera des informations complémentaires en info-bulle.";


$lang['dashboard']['help_mod1'] = "Pour modifier une valeur, vous pouvez modifier chacun de ces paramètres dans le formulaire ci-dessus";
$lang['dashboard']['help_mod2'] = "Vous pouvez cliquer sur \"informations de mesure\" pour obtenir les valeurs seuil, minimale, maximale et la fréquence de collecte de cet indicateur";
$lang['dashboard']['help_mod3'] = "Vous pouvez cliquer sur \"" . $lang['dashboard']['all_value'] . "\" pour afficher toutes les valeurs de cet indicateur pour cette échelle";
$lang['dashboard']['help_mod4'] = "Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \"revoir les paramètres\" pour les modifier";
$lang['dashboard']['help_mod5'] = "Vous devez absolument saisir une valeur numérique comprise entre les valeurs minimale et maximale prévues pour cet indicateur";
$lang['dashboard']['help_mod6'] = "Les champs marqués d'un astérisque sont obligatoires";


$lang['dashboard']['help_rap1'] = "Le rapport est édité au format pdf et lisible avec Acrobat reader";
$lang['dashboard']['help_rap2'] = "Faites le choix entre les différentes options proposées ci-dessus pour éditer votre rapport";
$lang['dashboard']['help_rap3'] = "Vous pouvez annuler l'édition du rapport à tout moment en cliquant sur annuler";


$lang['dashboard']['help_det2'] = "Vous pouvez ajouter une valeur à ce couple indicateur/échelle en cliquant sur l'icône d'ajout qui lui est associée en haut de page";
$lang['dashboard']['help_det3'] = "Vous pouvez modifier une valeur en cliquant sur l'icône de modification qui lui est associée";
$lang['dashboard']['help_det4'] = "Vous pouvez supprimer une valeur en cliquant sur l'icône de suppression qui lui est associée";
$lang['dashboard']['help_det1'] = "Attention, une valeur est associée à un indicateur mais aussi à une échelle";
$lang['dashboard']['help_det5'] = "Pour afficher les informations générales d'un indicateur, de réglementation, fournisseurs, et critères d'évaluation, cliquer sur afficher ces informations en bas de page.";


$lang['dashboard']['help_sup1'] = "En cliquant sur valider, la valeur est définitivement suppprimée.";
$lang['dashboard']['help_sup2'] = "Si vous voulez simplement désactiver la valeur, positionnez la en statut \"brouillon\" dans modification de valeur.";
?>
